@@ -39,11 +39,11 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       SUBROUTINE TWOSTAGE(WORK,DATASIZE,T,DELTA,GP,BOOTSN,ALPHA,EPS,
      +LRPV,MTPV,TSPV)
 
+      INTEGER WORK, BOOTSN
 
       INTEGER DELTA(WORK), GP(WORK), L(2,WORK), D(2,WORK), N(2,WORK),
      +   DELTA0(WORK), GP0(WORK), L0(2,WORK), D0(2,WORK), N0(2,WORK), 
-     +   NDT, N1, N2, NDT0, N10, N20, BOOTSN, I, J, NPLUS, NMINUS, 
-     +   IERROR, DATASIZE, WORK 
+     +   NDT, N1, N2, NDT0, N10, N20, J, NPLUS, NMINUS, DATASIZE
 
       DOUBLE PRECISION  T(WORK), DT(WORK), WEIGHT(WORK), T0(WORK), 
      +   DT0(WORK), ALPHA, ALPHA1, EPS, NULL, LRW, LRPV, MTW(BOOTSN), 
@@ -141,8 +141,9 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE MMANTEL(WORK, D, L, N, N1, N2, NDT, EPS,  WEIGHT)
 
-      INTEGER D(2,WORK),L(2,WORK),N(2,WORK),N1,N2,NDT,I,J,
-     +   CHP,LB,RB,WORK
+      INTEGER WORK, NDT
+      INTEGER D(2,WORK),L(2,WORK),N(2,WORK),N1,N2,I,J,
+     +   CHP,LB,RB
       DOUBLE PRECISION S(WORK), G(WORK), WEIGHT(WORK)
       DOUBLE PRECISION W, WABS, NUM, DENOM, VAR(NDT), EPS
 
@@ -249,7 +250,8 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE STATCAL(WORK, D, N, NDT, WEIGHT, W, PVAL2)
 
-      INTEGER I, D(2, WORK), N(2, WORK), NDT, WORK
+      INTEGER WORK, NDT
+      INTEGER I, D(2, WORK), N(2, WORK)
       DOUBLE PRECISION WEIGHT(WORK),NUM,DENOM,VAR(NDT),
      +   W,PVAL1,PVAL2,PNORM
 
@@ -291,8 +293,9 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       SUBROUTINE ARRANGEDATA(WORK,DATASIZE,T,DELTA,GP,N1,N2,
      +   NDT,DT,N,D,L)
 
+      INTEGER WORK
       INTEGER DATASIZE,DELTA(WORK),GP(WORK),L(2,WORK),D(2,WORK), 
-     +   N(2,WORK),NDT,N1,N2,WORK
+     +   N(2,WORK),NDT,N1,N2
       DOUBLE PRECISION T(WORK),DT(WORK)
 
       CALL SORTBYT(WORK,DATASIZE, T, DELTA, GP)
@@ -308,7 +311,8 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE COUNT(WORK,DATASIZE, GP, N1, N2)
 
-      INTEGER DATASIZE, GP(WORK), N1, N2, I, WORK
+      INTEGER WORK
+      INTEGER DATASIZE, GP(WORK), N1, N2, I
 
       N1=0
       N2=0
@@ -330,8 +334,9 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE SORTBYT(WORK,DATASIZE,T,DELTA,GP)
 
+      INTEGER WORK
       INTEGER DATASIZE,DELTA(WORK),GP(WORK),I,J,
-     +   DTEMP,GTEMP,WORK
+     +   DTEMP,GTEMP
       DOUBLE PRECISION T(WORK), TTEMP
 
       DO 10 I=1, DATASIZE-1
@@ -383,8 +388,9 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE SORTBYGP(WORK,DATASIZE,T,DELTA,GP)
 
+      INTEGER WORK
       INTEGER  DATASIZE,DELTA(WORK),GP(WORK),I,J,
-     +   DTEMP,GTEMP,WORK
+     +   DTEMP,GTEMP
       DOUBLE PRECISION  T(WORK), TTEMP
 
       DO 10 I = 1,(DATASIZE-1)
@@ -418,7 +424,8 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE TLDN(WORK,DATASIZE,T,DELTA,GP,N1,N2,L,D,DT,N,NDT)
 
-      INTEGER DATASIZE, DELTA(WORK), GP(WORK), N1,N2,WORK,
+      INTEGER WORK
+      INTEGER DATASIZE, DELTA(WORK), GP(WORK), N1,N2,
      +   L(2,WORK), D(2,WORK), N(2,WORK), NDT, PNTR, I, J
       DOUBLE PRECISION T(WORK), DT(WORK)       
 
@@ -508,9 +515,10 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 
       SUBROUTINE RESAMPLE1(N1,N2,T,DELTA,GP, T0,DELTA0,GP0)
 
-      INTEGER  N1, N2, I, X, DELTA(N1+N2),GP(N1+N2),DELTA0(N1+N2),
+      INTEGER  N1, N2
+      INTEGER  I, X, DELTA(N1+N2),GP(N1+N2),DELTA0(N1+N2),
      +   GP0(N1+N2)
-      DOUBLE PRECISION  T(N1+N2), T0(N1+N2), TEMP
+      DOUBLE PRECISION  T(N1+N2), T0(N1+N2)
 
       DOUBLE PRECISION unifrnd
       EXTERNAL unifrnd
